#!/bin/bash
#############################################
# Count GC nucleotides per window size for DNA sequence
#
# This bash script reads only ACTG/actg nucleotides and ignores everything else on the file (like N's). 
# The first line of the file is not ignored, and if it contains actg it will be taken into account, therefore the it is best be removed prior to running.
# If N is found, the script would ignore the entire Xbp window , so it is recommanded to clean the file from Ns prior to running it. 
# In the end of the script if there is a remaining (less than Xbp) it won't be counted.
#
# The line format of the original file doesn't matter.
#
# Run by: ./CalculateGCWindow.n x.txt 32
# To print output to file: 
#           ./CalculateGCWindow.n  x.fa > x_res
#           ./CalculateGCWindow.n  1.fa > 1_res
#
# Internal parameters: 
#       $1 - The DNA filename
#############################################
# Written by: Eran Elhaik
# Date: 1/1/2009
# Ver 1.04
# Website: http://nsm.uh.edu/~dgraur/eran/Simulation/main.htm
#############################################
cat $1 | awk '
BEGIN {
seq="";
win_size=32;
}
#^This matches the beginning of the string or the beginning of a line within the string
#[...]This is called a character set. It matches any one of the characters that are enclosed in the square brackets
/^[acgtACGTN]/ {seq=seq$1;			#Match pattern
   while (length(seq)>win_size) {
                winseq=substr(seq,1,win_size);	#return Xbp from 1:X of seq string
                #print winseq;
                seq=substr(seq,(win_size+1));		#now seq is the original but goes from 33:end 
                #print winseq;			#Print Xbp strings and in the next line- how many GC
                # print index(winseq,"N");
                if (index(winseq,"N")==0) {      # take off windows with N
                        gc=0;
                        for (i=1; i<=length(winseq); i++) {
                                c=substr(winseq,i,1);
                                if (c == "G" || c=="C" || c == "g" || c=="c") {
                                        gc=gc+1;
                                }
                        }
                        printf "%d ",gc;
                }

        }
        }
END {printf "\n"; }
'

